@@ -1,7 +1,8 @@
 import os.path
-import semver
-from typing import Any, Dict, List
 from pathlib import Path
+from typing import Any, Dict, List
+
+import semver
 
 from erdpy import errors, utils, workstation
 
@@ -91,7 +92,7 @@ def get_active() -> Dict[str, Any]:
     empty_config: Dict[str, Any] = dict()
     result: Dict[str, Any] = configs.get(active_config_name, empty_config)
 
-    return result;
+    return result
 
 
 def set_active(name: str):
@@ -169,7 +170,7 @@ def get_defaults() -> Dict[str, Any]:
         "dependencies.elrond_proxy_go.tag": "latest",
         "dependencies.elrond_proxy_go.urlTemplate.linux": "https://github.com/ElrondNetwork/elrond-proxy-go/archive/{TAG}.tar.gz",
         "dependencies.elrond_proxy_go.urlTemplate.osx": "https://github.com/ElrondNetwork/elrond-proxy-go/archive/{TAG}.tar.gz",
-        "dependencies.golang.tag": "go1.15.2",
+        "dependencies.golang.tag": "go1.18.4",
         "dependencies.golang.urlTemplate.linux": "https://golang.org/dl/{TAG}.linux-amd64.tar.gz",
         "dependencies.golang.urlTemplate.osx": "https://golang.org/dl/{TAG}.darwin-amd64.tar.gz",
         "dependencies.mcl_signer.tag": "latest",
@@ -177,9 +178,6 @@ def get_defaults() -> Dict[str, Any]:
         "dependencies.mcl_signer.urlTemplate.osx": "https://github.com/ElrondNetwork/elrond-sdk-go-tools/releases/download/{TAG}/mcl_signer_{TAG}_macos-latest.tar.gz",
         "dependencies.wasm-opt.tag": "latest",
         "dependencies.twiggy.tag": "latest",
-        "dependencies.wabt.tag": "1.0.27",
-        "dependencies.wabt.urlTemplate.linux": "https://github.com/WebAssembly/wabt/releases/download/{TAG}/wabt-{TAG}-ubuntu.tar.gz",
-        "dependencies.wabt.urlTemplate.osx": "https://github.com/WebAssembly/wabt/releases/download/{TAG}/wabt-{TAG}-macos.tar.gz",
         "dependencies.testwallets.tag": "latest",
         "dependencies.testwallets.urlTemplate.linux": "https://github.com/ElrondNetwork/elrond-sdk-testwallets/archive/{TAG}.tar.gz",
         "dependencies.testwallets.urlTemplate.osx": "https://github.com/ElrondNetwork/elrond-sdk-testwallets/archive/{TAG}.tar.gz",
