@@ -2,10 +2,11 @@ import logging
 import os
 import shutil
 from os import path
-from typing import Dict, List, Optional
 from pathlib import Path
+from typing import Dict, List, Optional
 
-from erdpy import config, dependencies, downloader, errors, myprocess, utils, workstation
+from erdpy import (config, dependencies, downloader, errors, myprocess, utils,
+                   workstation)
 
 logger = logging.getLogger("modules")
 
@@ -149,8 +150,8 @@ class VMToolsModule(StandaloneModule):
             aliases = list()
 
         super().__init__(key, aliases)
-        self.repo_name = 'wasm-vm'
-        self.organisation = 'ElrondNetwork'
+        self.repo_name = 'mx-vm-wasm-go'
+        self.organisation = 'multiversx'
 
     def _post_install(self, tag: str):
         dependencies.install_module('golang')
@@ -248,28 +249,6 @@ class NodejsModule(StandaloneModule):
         raise errors.UnsupportedConfigurationValue("Nodejs tag must always be explicit, not latest")
 
 
-
-class WabtModule(StandaloneModule):
-    def __init__(self, key: str, aliases: List[str]):
-        super().__init__(key, aliases)
-
-    def _post_install(self, tag: str):
-        # We'll create a "latest" symlink
-        link_target = path.join(self.get_directory(tag), f"wabt-{tag}")
-        link = path.join(self.get_parent_directory(), "latest")
-        utils.symlink(link_target, link)
-
-    def get_env(self):
-        bin_folder = path.join(self.get_parent_directory(), "latest", "bin")
-
-        return {
-            "PATH": f"{bin_folder}:{os.environ['PATH']}",
-        }
-
-    def get_latest_release(self) -> str:
-        raise errors.UnsupportedConfigurationValue("WABT tag must be explicit")
-
-
 class NpmModule(DependencyModule):
     def __init__(self, key: str, aliases: List[str] = []):
         super().__init__(key, aliases)
@@ -324,7 +303,7 @@ class Rust(DependencyModule):
 
         args = [rustup_path, "--verbose", "--default-toolchain", toolchain, "--profile",
                 "minimal", "--target", "wasm32-unknown-unknown", "--no-modify-path", "-y"]
-        myprocess.run_process(args, env=self.get_env())
+        myprocess.run_process(args, env=self.get_env_for_install())
 
     def uninstall(self, tag: str):
         directory = self.get_directory("")
@@ -333,7 +312,7 @@ class Rust(DependencyModule):
 
     def is_installed(self, tag: str) -> bool:
         try:
-            myprocess.run_process(["rustc", "--version"], env=self.get_env())
+            myprocess.run_process(["rustc", "--version"], env=self.get_env_for_is_installed())
             return True
         except Exception:
             return False
@@ -350,6 +329,27 @@ class Rust(DependencyModule):
         directory = self.get_directory("")
 
         return {
+            # At this moment, cc (build-essential) is sometimes required by the meta crate (e.g. for reports)
+            "PATH": f"{path.join(directory, 'bin')}:{os.environ['PATH']}",
+            "RUSTUP_HOME": directory,
+            "CARGO_HOME": directory
+        }
+
+    def get_env_for_is_installed(self):
+        directory = self.get_directory("")
+
+        return {
+            # Here, we do not include the system PATH
+            "PATH": f"{path.join(directory, 'bin')}",
+            "RUSTUP_HOME": directory,
+            "CARGO_HOME": directory
+        }
+
+    def get_env_for_install(self):
+        directory = self.get_directory("")
+
+        return {
+            # For installation, wget (or curl) and cc (build-essential) are also required.
             "PATH": f"{path.join(directory, 'bin')}:{os.environ['PATH']}",
             "RUSTUP_HOME": directory,
             "CARGO_HOME": directory
@@ -406,8 +406,8 @@ class MclSignerModule(StandaloneModule):
 class TestWalletsModule(StandaloneModule):
     def __init__(self, key: str):
         super().__init__(key, [])
-        self.organisation = "ElrondNetwork"
-        self.repo_name = "elrond-sdk-testwallets"
+        self.organisation = "multiversx"
+        self.repo_name = "mx-sdk-testwallets"
 
     def _post_install(self, tag: str):
         # We'll create a "latest" symlink
