@@ -6,7 +6,7 @@ from pathlib import Path
 from typing import List
 
 from erdpy import dependencies, errors, myprocess, utils
-from erdpy.projects.project_base import Project
+from erdpy.projects.project_base import Project, rename_wasm_files
 
 logger = logging.getLogger('ProjectClang')
 
@@ -109,7 +109,9 @@ class ProjectClang(Project):
                 ll_file.unlink()
             except FileNotFoundError:
                 pass
-        return [output_wasm_file]
+        
+        paths = rename_wasm_files([output_wasm_file], self.options.get("wasm-name"))
+        return paths
 
     def _get_llvm_path(self):
         return dependencies.get_module_directory('llvm')
