@@ -245,7 +245,7 @@ def query_latest_release_tag(repo: str) -> str:
     Queries the Github API to retrieve the latest released tag of the specified
     repository. The repository must be of the form 'organisation/project'.
     """
-    url = f'https://api.github.com/repos/{repo}/releases'
+    url = f'https://api.github.com/repos/{repo}/releases/latest'
 
     github_api_token = erdpy.config.get_value('github_api_token')
     headers = dict()
@@ -256,12 +256,9 @@ def query_latest_release_tag(repo: str) -> str:
     response = session.get(url, headers=headers)
     response.raise_for_status()
 
-    release_tags = [str(release['tag_name']) for release in response.json()]
-    try:
-        latest_release_tag = erdpy.config.get_latest_semver(release_tags)
-        return latest_release_tag
-    except IndexError:
-        raise Exception(f"no releases in {repo}")
+    release = response.json()
+    latest_release_tag: str = release['tag_name']
+    return latest_release_tag
 
 
 # https://code.visualstudio.com/docs/python/debugging
