@@ -1,12 +1,12 @@
 import json
-from os import path
+from pathlib import Path
 
 from erdpy import guards
 from erdpy.errors import CannotReadValidatorsData
 
 
 class ValidatorsFile:
-    def __init__(self, validators_file_path: str):
+    def __init__(self, validators_file_path: Path):
         self.validators_file_path = validators_file_path
         self._validators_data = self._read_json_file_validators()
 
@@ -17,7 +17,7 @@ class ValidatorsFile:
         return self._validators_data.get("validators", [])
 
     def _read_json_file_validators(self):
-        val_file = path.expanduser(self.validators_file_path)
+        val_file = self.validators_file_path.expanduser()
         guards.is_file(val_file)
         with open(self.validators_file_path, "r") as json_file:
             try:
